#include "newmacros.h"
#include "runtime.h"

#define CT_v416	((void*)startLabel+32)
#define CT_v440	((void*)startLabel+668)
#define FN_LAMBDA412	((void*)startLabel+772)
#define CT_v443	((void*)startLabel+792)
#define F0_LAMBDA412	((void*)startLabel+800)
#define FN_LAMBDA411	((void*)startLabel+828)
#define CT_v446	((void*)startLabel+848)
#define F0_LAMBDA411	((void*)startLabel+856)
#define FN_LAMBDA410	((void*)startLabel+884)
#define CT_v449	((void*)startLabel+904)
#define F0_LAMBDA410	((void*)startLabel+912)
#define FN_LAMBDA409	((void*)startLabel+940)
#define CT_v452	((void*)startLabel+960)
#define F0_LAMBDA409	((void*)startLabel+968)
#define FN_LAMBDA408	((void*)startLabel+996)
#define CT_v455	((void*)startLabel+1016)
#define F0_LAMBDA408	((void*)startLabel+1024)
#define FN_LAMBDA407	((void*)startLabel+1052)
#define CT_v458	((void*)startLabel+1072)
#define F0_LAMBDA407	((void*)startLabel+1080)
#define FN_LAMBDA406	((void*)startLabel+1108)
#define CT_v461	((void*)startLabel+1128)
#define F0_LAMBDA406	((void*)startLabel+1136)
#define FN_LAMBDA405	((void*)startLabel+1164)
#define CT_v464	((void*)startLabel+1184)
#define F0_LAMBDA405	((void*)startLabel+1192)
#define FN_LAMBDA404	((void*)startLabel+1220)
#define CT_v467	((void*)startLabel+1240)
#define F0_LAMBDA404	((void*)startLabel+1248)
#define FN_LAMBDA403	((void*)startLabel+1276)
#define CT_v470	((void*)startLabel+1296)
#define F0_LAMBDA403	((void*)startLabel+1304)
#define FN_LAMBDA402	((void*)startLabel+1332)
#define CT_v473	((void*)startLabel+1352)
#define F0_LAMBDA402	((void*)startLabel+1360)
#define FN_LAMBDA401	((void*)startLabel+1388)
#define CT_v476	((void*)startLabel+1408)
#define F0_LAMBDA401	((void*)startLabel+1416)
#define ST_v415	((void*)startLabel+1436)
#define ST_v420	((void*)startLabel+1456)
#define PP_LAMBDA402	((void*)startLabel+1471)
#define PC_LAMBDA402	((void*)startLabel+1471)
#define ST_v472	((void*)startLabel+1471)
#define PP_LAMBDA403	((void*)startLabel+1498)
#define PC_LAMBDA403	((void*)startLabel+1498)
#define ST_v469	((void*)startLabel+1498)
#define PP_LAMBDA404	((void*)startLabel+1525)
#define PC_LAMBDA404	((void*)startLabel+1525)
#define ST_v466	((void*)startLabel+1525)
#define PP_LAMBDA405	((void*)startLabel+1552)
#define PC_LAMBDA405	((void*)startLabel+1552)
#define ST_v463	((void*)startLabel+1552)
#define PP_LAMBDA406	((void*)startLabel+1579)
#define PC_LAMBDA406	((void*)startLabel+1579)
#define ST_v460	((void*)startLabel+1579)
#define PP_LAMBDA407	((void*)startLabel+1606)
#define PC_LAMBDA407	((void*)startLabel+1606)
#define ST_v457	((void*)startLabel+1606)
#define PP_LAMBDA408	((void*)startLabel+1633)
#define PC_LAMBDA408	((void*)startLabel+1633)
#define ST_v454	((void*)startLabel+1633)
#define PP_LAMBDA409	((void*)startLabel+1660)
#define PC_LAMBDA409	((void*)startLabel+1660)
#define ST_v451	((void*)startLabel+1660)
#define PP_LAMBDA410	((void*)startLabel+1687)
#define PC_LAMBDA410	((void*)startLabel+1687)
#define ST_v448	((void*)startLabel+1687)
#define PP_LAMBDA411	((void*)startLabel+1714)
#define PC_LAMBDA411	((void*)startLabel+1714)
#define ST_v445	((void*)startLabel+1714)
#define PP_LAMBDA412	((void*)startLabel+1741)
#define PC_LAMBDA412	((void*)startLabel+1741)
#define ST_v442	((void*)startLabel+1741)
#define PP_LAMBDA401	((void*)startLabel+1768)
#define PC_LAMBDA401	((void*)startLabel+1768)
#define ST_v475	((void*)startLabel+1768)
#define PS_v414	((void*)startLabel+1796)
#define PS_v438	((void*)startLabel+1808)
#define PS_v439	((void*)startLabel+1820)
#define PS_v422	((void*)startLabel+1832)
#define PS_v419	((void*)startLabel+1844)
#define PS_v435	((void*)startLabel+1856)
#define PS_v436	((void*)startLabel+1868)
#define PS_v437	((void*)startLabel+1880)
#define PS_v423	((void*)startLabel+1892)
#define PS_v424	((void*)startLabel+1904)
#define PS_v425	((void*)startLabel+1916)
#define PS_v426	((void*)startLabel+1928)
#define PS_v427	((void*)startLabel+1940)
#define PS_v428	((void*)startLabel+1952)
#define PS_v429	((void*)startLabel+1964)
#define PS_v430	((void*)startLabel+1976)
#define PS_v431	((void*)startLabel+1988)
#define PS_v432	((void*)startLabel+2000)
#define PS_v433	((void*)startLabel+2012)
#define PS_v434	((void*)startLabel+2024)
#define PS_v474	((void*)startLabel+2036)
#define PS_v471	((void*)startLabel+2048)
#define PS_v468	((void*)startLabel+2060)
#define PS_v465	((void*)startLabel+2072)
#define PS_v462	((void*)startLabel+2084)
#define PS_v459	((void*)startLabel+2096)
#define PS_v456	((void*)startLabel+2108)
#define PS_v453	((void*)startLabel+2120)
#define PS_v450	((void*)startLabel+2132)
#define PS_v447	((void*)startLabel+2144)
#define PS_v444	((void*)startLabel+2156)
#define PS_v441	((void*)startLabel+2168)
void FR_Time_46hs_95toUTCTime(void);
extern Node FN_Prelude_46Enum_46Time_46Month_46toEnum[];
extern Node FN_Prelude_46Integral_46Prelude_46Int_46toInteger[];
extern Node FN_Prelude_46Enum_46Time_46Day_46toEnum[];
extern Node FN_CString_46fromCString[];
extern Node PM_Time[];
extern Node PC_CString_46fromCString[];
extern Node PC_Time_46CalendarTime[];
extern Node PC_Prelude_46Enum_46Time_46Month_46toEnum[];
extern Node PC_Prelude_46Integral_46Prelude_46Int_46toInteger[];
extern Node PC_Prelude_46Enum_46Time_46Day_46toEnum[];

static Node startLabel[] = {
  bytes2word(1,0,0,1)
, useLabel(CT_v416)
,};
Node FN_Time_46hs_95toUTCTime[] = {
  bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PRIMITIVE)
, useLabel(FR_Time_46hs_95toUTCTime)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 70001
, useLabel(ST_v415)
,	/* CT_v416: (byte 0) */
  HW(0,1)
, 0
,};
Node F0_Time_46hs_95toUTCTime[] = {
  CAPTAG(useLabel(FN_Time_46hs_95toUTCTime),1)
, useLabel(PS_v414)
, 0
, 0
, 0
, bytes2word(1,0,0,1)
, useLabel(CT_v440)
,};
Node FN_Time_46toUTCTime[] = {
  bytes2word(NEEDSTACK_I16,PUSH_ZAP_ARG_I1,EVAL,NEEDHEAP_P1)
, bytes2word(119,UNPACK,1,PUSH_HEAP)
, bytes2word(HEAP_CVAL_P1,7,HEAP_CVAL_N1,7)
, bytes2word(HEAP_CREATE,HEAP_SPACE,HEAP_SPACE,HEAP_I1)
, bytes2word(PUSH_HEAP,HEAP_CVAL_P1,8,HEAP_CVAL_N1)
, bytes2word(12,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(HEAP_OFF_N1,11,PUSH_HEAP,HEAP_CVAL_P1)
, bytes2word(9,HEAP_CVAL_N1,17,HEAP_CREATE)
, bytes2word(HEAP_SPACE,HEAP_SPACE,HEAP_OFF_N1,17)
, bytes2word(PUSH_HEAP,HEAP_CVAL_P1,10,HEAP_CVAL_N1)
, bytes2word(22,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(HEAP_OFF_N1,23,PUSH_HEAP,HEAP_CVAL_P1)
, bytes2word(11,HEAP_CVAL_N1,27,HEAP_CREATE)
, bytes2word(HEAP_SPACE,HEAP_SPACE,HEAP_OFF_N1,29)
, bytes2word(PUSH_HEAP,HEAP_CVAL_P1,12,HEAP_CVAL_N1)
, bytes2word(32,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(HEAP_OFF_N1,35,PUSH_HEAP,HEAP_CVAL_P1)
, bytes2word(13,HEAP_CVAL_N1,37,HEAP_CREATE)
, bytes2word(HEAP_SPACE,HEAP_SPACE,HEAP_OFF_N1,41)
, bytes2word(PUSH_HEAP,HEAP_CVAL_P1,14,HEAP_CVAL_N1)
, bytes2word(42,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(HEAP_OFF_N1,47,PUSH_HEAP,HEAP_CVAL_P1)
, bytes2word(15,HEAP_CVAL_N1,47,HEAP_CREATE)
, bytes2word(HEAP_SPACE,HEAP_SPACE,HEAP_OFF_N1,53)
, bytes2word(PUSH_HEAP,HEAP_CVAL_P1,16,HEAP_CVAL_N1)
, bytes2word(52,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(HEAP_OFF_N1,59,PUSH_HEAP,HEAP_CVAL_P1)
, bytes2word(17,HEAP_CVAL_N1,57,HEAP_CREATE)
, bytes2word(HEAP_SPACE,HEAP_SPACE,HEAP_OFF_N1,65)
, bytes2word(PUSH_HEAP,HEAP_CVAL_P1,18,HEAP_CVAL_N1)
, bytes2word(62,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(HEAP_OFF_N1,71,PUSH_HEAP,HEAP_CVAL_P1)
, bytes2word(19,HEAP_CVAL_N1,67,HEAP_CREATE)
, bytes2word(HEAP_SPACE,HEAP_SPACE,HEAP_OFF_N1,77)
, bytes2word(HEAP_CVAL_P1,20,HEAP_CVAL_N1,72)
, bytes2word(HEAP_CREATE,HEAP_SPACE,HEAP_SPACE,HEAP_P1)
, bytes2word(10,HEAP_CVAL_P1,21,HEAP_CVAL_N1)
, bytes2word(77,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(HEAP_P1,5,HEAP_CVAL_P1,22)
, bytes2word(HEAP_CVAL_N1,82,HEAP_CREATE,HEAP_SPACE)
, bytes2word(HEAP_SPACE,HEAP_P1,4,HEAP_CVAL_P1)
, bytes2word(23,HEAP_CVAL_N1,87,HEAP_CREATE)
, bytes2word(HEAP_SPACE,HEAP_SPACE,HEAP_I2,PUSH_HEAP)
, bytes2word(HEAP_CVAL_N1,92,HEAP_CVAL_N1,97)
, bytes2word(HEAP_CREATE,HEAP_SPACE,HEAP_SPACE,HEAP_P1)
, bytes2word(12,HEAP_OFF_N1,30,HEAP_P1)
, bytes2word(10,HEAP_P1,9,HEAP_P1)
, bytes2word(8,HEAP_P1,7,HEAP_OFF_N1)
, bytes2word(29,HEAP_OFF_N1,24,HEAP_P1)
, bytes2word(4,HEAP_OFF_N1,20,HEAP_I2)
, bytes2word(HEAP_I1,RETURN,ENDCODE,0)
, bytes2word(0,0,0,0)
, 0
, useLabel(PS_v439)
, 0
, 0
, 0
, 0
, CONSTR(0,12,0)
, 0
, 0
, 0
, 0
, useLabel(PS_v438)
, 0
, 0
, 0
, 0
, useLabel(PS_v437)
, 0
, 0
, 0
, 0
, useLabel(PS_v436)
, 0
, 0
, 0
, 0
, useLabel(PS_v435)
, 0
, 0
, 0
, 0
, useLabel(PS_v434)
, 0
, 0
, 0
, 0
, useLabel(PS_v433)
, 0
, 0
, 0
, 0
, useLabel(PS_v432)
, 0
, 0
, 0
, 0
, useLabel(PS_v431)
, 0
, 0
, 0
, 0
, useLabel(PS_v430)
, 0
, 0
, 0
, 0
, useLabel(PS_v429)
, 0
, 0
, 0
, 0
, useLabel(PS_v428)
, 0
, 0
, 0
, 0
, useLabel(PS_v427)
, 0
, 0
, 0
, 0
, useLabel(PS_v426)
, 0
, 0
, 0
, 0
, useLabel(PS_v425)
, 0
, 0
, 0
, 0
, useLabel(PS_v424)
, 0
, 0
, 0
, 0
, useLabel(PS_v423)
, 0
, 0
, 0
, 0
, useLabel(PS_v422)
, 0
, 0
, 0
, 0
, 100001
, useLabel(ST_v420)
,	/* CT_v440: (byte 0) */
  HW(17,1)
, 0
,};
Node F0_Time_46toUTCTime[] = {
  CAPTAG(useLabel(FN_Time_46toUTCTime),1)
, useLabel(PS_v419)
, 0
, 0
, 0
, VAPTAG(useLabel(FN_Time_46hs_95toUTCTime))
, VAPTAG(useLabel(FN_LAMBDA401))
, VAPTAG(useLabel(FN_LAMBDA402))
, VAPTAG(useLabel(FN_LAMBDA403))
, VAPTAG(useLabel(FN_LAMBDA404))
, VAPTAG(useLabel(FN_LAMBDA405))
, VAPTAG(useLabel(FN_LAMBDA406))
, VAPTAG(useLabel(FN_LAMBDA407))
, VAPTAG(useLabel(FN_LAMBDA408))
, VAPTAG(useLabel(FN_LAMBDA409))
, VAPTAG(useLabel(FN_LAMBDA410))
, VAPTAG(useLabel(FN_LAMBDA411))
, VAPTAG(useLabel(FN_LAMBDA412))
, VAPTAG(useLabel(FN_Prelude_46Enum_46Time_46Month_46toEnum))
, VAPTAG(useLabel(FN_Prelude_46Integral_46Prelude_46Int_46toInteger))
, VAPTAG(useLabel(FN_Prelude_46Enum_46Time_46Day_46toEnum))
, VAPTAG(useLabel(FN_CString_46fromCString))
, bytes2word(1,0,0,1)
, useLabel(CT_v443)
,	/* FN_LAMBDA412: (byte 0) */
  bytes2word(NEEDSTACK_I16,SELECTOR_EVAL,SELECT,12)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 110065
, useLabel(ST_v442)
,	/* CT_v443: (byte 0) */
  HW(0,1)
, 0
,	/* F0_LAMBDA412: (byte 0) */
  CAPTAG(useLabel(FN_LAMBDA412),1)
, useLabel(PS_v441)
, 0
, 0
, 0
, bytes2word(1,0,0,1)
, useLabel(CT_v446)
,	/* FN_LAMBDA411: (byte 0) */
  bytes2word(NEEDSTACK_I16,SELECTOR_EVAL,SELECT,11)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 110059
, useLabel(ST_v445)
,	/* CT_v446: (byte 0) */
  HW(0,1)
, 0
,	/* F0_LAMBDA411: (byte 0) */
  CAPTAG(useLabel(FN_LAMBDA411),1)
, useLabel(PS_v444)
, 0
, 0
, 0
, bytes2word(1,0,0,1)
, useLabel(CT_v449)
,	/* FN_LAMBDA410: (byte 0) */
  bytes2word(NEEDSTACK_I16,SELECTOR_EVAL,SELECT,10)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 110053
, useLabel(ST_v448)
,	/* CT_v449: (byte 0) */
  HW(0,1)
, 0
,	/* F0_LAMBDA410: (byte 0) */
  CAPTAG(useLabel(FN_LAMBDA410),1)
, useLabel(PS_v447)
, 0
, 0
, 0
, bytes2word(1,0,0,1)
, useLabel(CT_v452)
,	/* FN_LAMBDA409: (byte 0) */
  bytes2word(NEEDSTACK_I16,SELECTOR_EVAL,SELECT,9)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 110048
, useLabel(ST_v451)
,	/* CT_v452: (byte 0) */
  HW(0,1)
, 0
,	/* F0_LAMBDA409: (byte 0) */
  CAPTAG(useLabel(FN_LAMBDA409),1)
, useLabel(PS_v450)
, 0
, 0
, 0
, bytes2word(1,0,0,1)
, useLabel(CT_v455)
,	/* FN_LAMBDA408: (byte 0) */
  bytes2word(NEEDSTACK_I16,SELECTOR_EVAL,SELECT,8)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 110043
, useLabel(ST_v454)
,	/* CT_v455: (byte 0) */
  HW(0,1)
, 0
,	/* F0_LAMBDA408: (byte 0) */
  CAPTAG(useLabel(FN_LAMBDA408),1)
, useLabel(PS_v453)
, 0
, 0
, 0
, bytes2word(1,0,0,1)
, useLabel(CT_v458)
,	/* FN_LAMBDA407: (byte 0) */
  bytes2word(NEEDSTACK_I16,SELECTOR_EVAL,SELECT,7)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 110038
, useLabel(ST_v457)
,	/* CT_v458: (byte 0) */
  HW(0,1)
, 0
,	/* F0_LAMBDA407: (byte 0) */
  CAPTAG(useLabel(FN_LAMBDA407),1)
, useLabel(PS_v456)
, 0
, 0
, 0
, bytes2word(1,0,0,1)
, useLabel(CT_v461)
,	/* FN_LAMBDA406: (byte 0) */
  bytes2word(NEEDSTACK_I16,SELECTOR_EVAL,SELECT,6)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 110033
, useLabel(ST_v460)
,	/* CT_v461: (byte 0) */
  HW(0,1)
, 0
,	/* F0_LAMBDA406: (byte 0) */
  CAPTAG(useLabel(FN_LAMBDA406),1)
, useLabel(PS_v459)
, 0
, 0
, 0
, bytes2word(1,0,0,1)
, useLabel(CT_v464)
,	/* FN_LAMBDA405: (byte 0) */
  bytes2word(NEEDSTACK_I16,SELECTOR_EVAL,SELECT,5)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 110028
, useLabel(ST_v463)
,	/* CT_v464: (byte 0) */
  HW(0,1)
, 0
,	/* F0_LAMBDA405: (byte 0) */
  CAPTAG(useLabel(FN_LAMBDA405),1)
, useLabel(PS_v462)
, 0
, 0
, 0
, bytes2word(1,0,0,1)
, useLabel(CT_v467)
,	/* FN_LAMBDA404: (byte 0) */
  bytes2word(NEEDSTACK_I16,SELECTOR_EVAL,SELECT,4)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 110023
, useLabel(ST_v466)
,	/* CT_v467: (byte 0) */
  HW(0,1)
, 0
,	/* F0_LAMBDA404: (byte 0) */
  CAPTAG(useLabel(FN_LAMBDA404),1)
, useLabel(PS_v465)
, 0
, 0
, 0
, bytes2word(1,0,0,1)
, useLabel(CT_v470)
,	/* FN_LAMBDA403: (byte 0) */
  bytes2word(NEEDSTACK_I16,SELECTOR_EVAL,SELECT,3)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 110018
, useLabel(ST_v469)
,	/* CT_v470: (byte 0) */
  HW(0,1)
, 0
,	/* F0_LAMBDA403: (byte 0) */
  CAPTAG(useLabel(FN_LAMBDA403),1)
, useLabel(PS_v468)
, 0
, 0
, 0
, bytes2word(1,0,0,1)
, useLabel(CT_v473)
,	/* FN_LAMBDA402: (byte 0) */
  bytes2word(NEEDSTACK_I16,SELECTOR_EVAL,SELECT,2)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 110013
, useLabel(ST_v472)
,	/* CT_v473: (byte 0) */
  HW(0,1)
, 0
,	/* F0_LAMBDA402: (byte 0) */
  CAPTAG(useLabel(FN_LAMBDA402),1)
, useLabel(PS_v471)
, 0
, 0
, 0
, bytes2word(1,0,0,1)
, useLabel(CT_v476)
,	/* FN_LAMBDA401: (byte 0) */
  bytes2word(NEEDSTACK_I16,SELECTOR_EVAL,SELECT,1)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 110008
, useLabel(ST_v475)
,	/* CT_v476: (byte 0) */
  HW(0,1)
, 0
,	/* F0_LAMBDA401: (byte 0) */
  CAPTAG(useLabel(FN_LAMBDA401),1)
, useLabel(PS_v474)
, 0
, 0
, 0
,};
Node PP_Time_46hs_95toUTCTime[] = {
 };
Node PC_Time_46hs_95toUTCTime[] = {
 	/* ST_v415: (byte 0) */
  bytes2word(84,105,109,101)
, bytes2word(46,104,115,95)
, bytes2word(116,111,85,84)
, bytes2word(67,84,105,109)
, bytes2word(101,0,0,0)
,};
Node PP_Time_46toUTCTime[] = {
 };
Node PC_Time_46toUTCTime[] = {
 	/* ST_v420: (byte 0) */
  bytes2word(84,105,109,101)
, bytes2word(46,116,111,85)
, bytes2word(84,67,84,105)
,	/* PP_LAMBDA402: (byte 3) */
 	/* PC_LAMBDA402: (byte 3) */
 	/* ST_v472: (byte 3) */
  bytes2word(109,101,0,84)
, bytes2word(105,109,101,46)
, bytes2word(116,111,85,84)
, bytes2word(67,84,105,109)
, bytes2word(101,58,49,49)
, bytes2word(58,49,51,45)
, bytes2word(49,49,58,49)
,	/* PP_LAMBDA403: (byte 2) */
 	/* PC_LAMBDA403: (byte 2) */
 	/* ST_v469: (byte 2) */
  bytes2word(54,0,84,105)
, bytes2word(109,101,46,116)
, bytes2word(111,85,84,67)
, bytes2word(84,105,109,101)
, bytes2word(58,49,49,58)
, bytes2word(49,56,45,49)
, bytes2word(49,58,50,49)
,	/* PP_LAMBDA404: (byte 1) */
 	/* PC_LAMBDA404: (byte 1) */
 	/* ST_v466: (byte 1) */
  bytes2word(0,84,105,109)
, bytes2word(101,46,116,111)
, bytes2word(85,84,67,84)
, bytes2word(105,109,101,58)
, bytes2word(49,49,58,50)
, bytes2word(51,45,49,49)
,	/* PP_LAMBDA405: (byte 4) */
 	/* PC_LAMBDA405: (byte 4) */
 	/* ST_v463: (byte 4) */
  bytes2word(58,50,54,0)
, bytes2word(84,105,109,101)
, bytes2word(46,116,111,85)
, bytes2word(84,67,84,105)
, bytes2word(109,101,58,49)
, bytes2word(49,58,50,56)
, bytes2word(45,49,49,58)
,	/* PP_LAMBDA406: (byte 3) */
 	/* PC_LAMBDA406: (byte 3) */
 	/* ST_v460: (byte 3) */
  bytes2word(51,49,0,84)
, bytes2word(105,109,101,46)
, bytes2word(116,111,85,84)
, bytes2word(67,84,105,109)
, bytes2word(101,58,49,49)
, bytes2word(58,51,51,45)
, bytes2word(49,49,58,51)
,	/* PP_LAMBDA407: (byte 2) */
 	/* PC_LAMBDA407: (byte 2) */
 	/* ST_v457: (byte 2) */
  bytes2word(54,0,84,105)
, bytes2word(109,101,46,116)
, bytes2word(111,85,84,67)
, bytes2word(84,105,109,101)
, bytes2word(58,49,49,58)
, bytes2word(51,56,45,49)
, bytes2word(49,58,52,49)
,	/* PP_LAMBDA408: (byte 1) */
 	/* PC_LAMBDA408: (byte 1) */
 	/* ST_v454: (byte 1) */
  bytes2word(0,84,105,109)
, bytes2word(101,46,116,111)
, bytes2word(85,84,67,84)
, bytes2word(105,109,101,58)
, bytes2word(49,49,58,52)
, bytes2word(51,45,49,49)
,	/* PP_LAMBDA409: (byte 4) */
 	/* PC_LAMBDA409: (byte 4) */
 	/* ST_v451: (byte 4) */
  bytes2word(58,52,54,0)
, bytes2word(84,105,109,101)
, bytes2word(46,116,111,85)
, bytes2word(84,67,84,105)
, bytes2word(109,101,58,49)
, bytes2word(49,58,52,56)
, bytes2word(45,49,49,58)
,	/* PP_LAMBDA410: (byte 3) */
 	/* PC_LAMBDA410: (byte 3) */
 	/* ST_v448: (byte 3) */
  bytes2word(53,49,0,84)
, bytes2word(105,109,101,46)
, bytes2word(116,111,85,84)
, bytes2word(67,84,105,109)
, bytes2word(101,58,49,49)
, bytes2word(58,53,51,45)
, bytes2word(49,49,58,53)
,	/* PP_LAMBDA411: (byte 2) */
 	/* PC_LAMBDA411: (byte 2) */
 	/* ST_v445: (byte 2) */
  bytes2word(55,0,84,105)
, bytes2word(109,101,46,116)
, bytes2word(111,85,84,67)
, bytes2word(84,105,109,101)
, bytes2word(58,49,49,58)
, bytes2word(53,57,45,49)
, bytes2word(49,58,54,51)
,	/* PP_LAMBDA412: (byte 1) */
 	/* PC_LAMBDA412: (byte 1) */
 	/* ST_v442: (byte 1) */
  bytes2word(0,84,105,109)
, bytes2word(101,46,116,111)
, bytes2word(85,84,67,84)
, bytes2word(105,109,101,58)
, bytes2word(49,49,58,54)
, bytes2word(53,45,49,49)
,	/* PP_LAMBDA401: (byte 4) */
 	/* PC_LAMBDA401: (byte 4) */
 	/* ST_v475: (byte 4) */
  bytes2word(58,54,57,0)
, bytes2word(84,105,109,101)
, bytes2word(46,116,111,85)
, bytes2word(84,67,84,105)
, bytes2word(109,101,58,49)
, bytes2word(49,58,56,45)
, bytes2word(49,49,58,49)
, bytes2word(49,0,0,0)
,	/* PS_v414: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_Time_46hs_95toUTCTime)
, useLabel(PC_Time_46hs_95toUTCTime)
,	/* PS_v438: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_Time_46toUTCTime)
, useLabel(PC_CString_46fromCString)
,	/* PS_v439: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_Time_46toUTCTime)
, useLabel(PC_Time_46CalendarTime)
,	/* PS_v422: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_Time_46toUTCTime)
, useLabel(PC_Time_46hs_95toUTCTime)
,	/* PS_v419: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_Time_46toUTCTime)
, useLabel(PC_Time_46toUTCTime)
,	/* PS_v435: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_Time_46toUTCTime)
, useLabel(PC_Prelude_46Enum_46Time_46Month_46toEnum)
,	/* PS_v436: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_Time_46toUTCTime)
, useLabel(PC_Prelude_46Integral_46Prelude_46Int_46toInteger)
,	/* PS_v437: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_Time_46toUTCTime)
, useLabel(PC_Prelude_46Enum_46Time_46Day_46toEnum)
,	/* PS_v423: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_Time_46toUTCTime)
, useLabel(PC_LAMBDA401)
,	/* PS_v424: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_Time_46toUTCTime)
, useLabel(PC_LAMBDA402)
,	/* PS_v425: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_Time_46toUTCTime)
, useLabel(PC_LAMBDA403)
,	/* PS_v426: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_Time_46toUTCTime)
, useLabel(PC_LAMBDA404)
,	/* PS_v427: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_Time_46toUTCTime)
, useLabel(PC_LAMBDA405)
,	/* PS_v428: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_Time_46toUTCTime)
, useLabel(PC_LAMBDA406)
,	/* PS_v429: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_Time_46toUTCTime)
, useLabel(PC_LAMBDA407)
,	/* PS_v430: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_Time_46toUTCTime)
, useLabel(PC_LAMBDA408)
,	/* PS_v431: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_Time_46toUTCTime)
, useLabel(PC_LAMBDA409)
,	/* PS_v432: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_Time_46toUTCTime)
, useLabel(PC_LAMBDA410)
,	/* PS_v433: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_Time_46toUTCTime)
, useLabel(PC_LAMBDA411)
,	/* PS_v434: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_Time_46toUTCTime)
, useLabel(PC_LAMBDA412)
,	/* PS_v474: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_LAMBDA401)
, useLabel(PC_LAMBDA401)
,	/* PS_v471: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_LAMBDA402)
, useLabel(PC_LAMBDA402)
,	/* PS_v468: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_LAMBDA403)
, useLabel(PC_LAMBDA403)
,	/* PS_v465: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_LAMBDA404)
, useLabel(PC_LAMBDA404)
,	/* PS_v462: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_LAMBDA405)
, useLabel(PC_LAMBDA405)
,	/* PS_v459: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_LAMBDA406)
, useLabel(PC_LAMBDA406)
,	/* PS_v456: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_LAMBDA407)
, useLabel(PC_LAMBDA407)
,	/* PS_v453: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_LAMBDA408)
, useLabel(PC_LAMBDA408)
,	/* PS_v450: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_LAMBDA409)
, useLabel(PC_LAMBDA409)
,	/* PS_v447: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_LAMBDA410)
, useLabel(PC_LAMBDA410)
,	/* PS_v444: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_LAMBDA411)
, useLabel(PC_LAMBDA411)
,	/* PS_v441: (byte 0) */
  useLabel(PM_Time)
, useLabel(PP_LAMBDA412)
, useLabel(PC_LAMBDA412)
,};

#include <haskell2c.h>
#include <HsFFI.h>

/* foreign import ccall "hs_toUTCTime" Time.hs_toUTCTime 1 :: Prelude.Int -> Prelude.12 */
extern NodePtr hs_toUTCTime(HsInt);
#ifdef PROFILE
static SInfo pf_Time_46hs_95toUTCTime = {"Time","Time.hs_toUTCTime","Prelude.12"};
#endif
C_HEADER(FR_Time_46hs_95toUTCTime) {
  NodePtr nodeptr;
  NodePtr result;
  HsInt arg1;
  nodeptr = C_GETARG1(1);
  IND_REMOVE(nodeptr);
  arg1 = (HsInt)GET_INT_VALUE(nodeptr);

  result = hs_toUTCTime(arg1);

  nodeptr = result;
  INIT_PROFINFO(nodeptr,&pf_Time_46hs_95toUTCTime);
  C_RETURN(nodeptr);
}
